@@ -59,6 +59,12 @@ class IndexDefinition:
     expression: str  # what will be indexed - typically a name of column, but may be more
     granularity: int = 1
 
+    def definition(self) -> str:
+        return (
+            f"INDEX {self.name} ({self.expression}) TYPE {self.type} GRANULARITY "
+            f"{self.granularity}"
+        )
+
 
 @dataclass
 class TableMetaParams:
@@ -105,7 +111,7 @@ class ClickhouseCubeBackend(CubeBackend):
         self._table_exists = {}
 
     def create_table(self, cube: Type[Cube]):
-        table_name = self._cube_to_table_name(cube)
+        table_name = self.cube_to_table_name(cube)
         if not self._table_exists.get(table_name, False):
             self._init_table(cube)
             self._create_materialized_views(cube)
@@ -118,7 +124,7 @@ class ClickhouseCubeBackend(CubeBackend):
             meta = self.get_table_meta(cube)
             clean_records = cube.cleanup_records(records)
             client.execute(
-                f"INSERT INTO {self.database}.{self._cube_to_table_name(cube)} VALUES ",
+                f"INSERT INTO {self.database}.{self.cube_to_table_name(cube)} VALUES ",
                 ({**rec._asdict(), meta.sign_col: 1} for rec in clean_records),
             )
 
@@ -167,7 +173,7 @@ class ClickhouseCubeBackend(CubeBackend):
         text, params, fields, _matview = self._prepare_db_query(
             query, auto_use_materialized_views=False, append_to_select=", -1"
         )
-        table = f"{self.database}.{self._cube_to_table_name(query.cube)}"
+        table = f"{self.database}.{self.cube_to_table_name(query.cube)}"
         field_names = ",".join(fields)
         meta = self.get_table_meta(query.cube)
 
@@ -226,7 +232,7 @@ class ClickhouseCubeBackend(CubeBackend):
 
         select = ", ".join(select_parts) + append_to_select
         group_by = ", ".join(grp.name for grp in query.groups)
-        table = f"{self.database}.{self._cube_to_table_name(matview if matview else query.cube)}"
+        table = f"{self.database}.{self.cube_to_table_name(matview if matview else query.cube)}"
         # ordering
         order_by = ", ".join(f"{ob.dimension.name} {ob.direction.name}" for ob in query.orderings)
         where_parts = []
@@ -303,14 +309,14 @@ class ClickhouseCubeBackend(CubeBackend):
             return agg.name
         raise ValueError(f"Unsupported aggregation {agg}")
 
-    def _cube_to_table_name(self, cube: Union[Type[Cube], Type[AggregatingMaterializedView]]):
+    def cube_to_table_name(self, cube: Union[Type[Cube], Type[AggregatingMaterializedView]]):
         return cube.__name__
 
     def _init_table(self, cube: Type[Cube]):
         """
         Creates the corresponding db table if the table is not yet present.
         """
-        name = self._cube_to_table_name(cube)
+        name = self.cube_to_table_name(cube)
         meta = self.get_table_meta(cube)
         fields = [
             f"{dim.name} {self._ch_type(dim)}"
@@ -318,13 +324,7 @@ class ClickhouseCubeBackend(CubeBackend):
         ]
         field_part = ", ".join(fields)
         # indexes
-        indexes = []
-        idx: IndexDefinition
-        for idx in meta.indexes:
-            indexes.append(
-                f"INDEX {idx.name} ({idx.expression}) TYPE {idx.type} GRANULARITY {idx.granularity}"
-            )
-        idx_part = ", ".join(indexes)
+        idx_part = ", ".join([idx.definition() for idx in meta.indexes])
         if idx_part:
             field_part += ", " + idx_part
         # sorting key
@@ -400,8 +400,8 @@ class ClickhouseCubeBackend(CubeBackend):
             for agg in matview._aggregations
         ]
         agg_part = ", ".join(aggregs)
-        table_name = self._cube_to_table_name(cube)
-        view_name = self._cube_to_table_name(matview)
+        table_name = self.cube_to_table_name(cube)
+        view_name = self.cube_to_table_name(matview)
         pop = "POPULATE" if populate else ""
         command = (
             f"CREATE MATERIALIZED VIEW IF NOT EXISTS {self.database}.{view_name} "
@@ -422,8 +422,8 @@ class ClickhouseCubeBackend(CubeBackend):
             for agg in matview._aggregations
         ]
         agg_part = ", ".join(aggregs)
-        table_name = self._cube_to_table_name(cube)
-        view_name = self._cube_to_table_name(matview)
+        table_name = self.cube_to_table_name(cube)
+        view_name = self.cube_to_table_name(matview)
         command = (
             f"ALTER TABLE {self.database}.{table_name} ADD PROJECTION IF NOT EXISTS {view_name} "
             f"(SELECT {preserved}, {agg_part} GROUP BY {preserved});"
