@@ -82,7 +82,7 @@ class PostgresCubeBackend(CubeBackend):
         clean_records = cube.cleanup_records(records)
         values_part = ", ".join(f"%({field})s" for field in cube.record_type()._fields)
         self._execute(
-            f"INSERT INTO {self.schema}.{self._cube_to_table_name(cube)} VALUES ({values_part});",
+            f"INSERT INTO {self.schema}.{self.cube_to_table_name(cube)} VALUES ({values_part});",
             [{**rec._asdict()} for rec in clean_records],
             exec_many=True,
         )
@@ -147,7 +147,7 @@ class PostgresCubeBackend(CubeBackend):
             select_parts = fields[:]
         select = ", ".join(select_parts)
         group_by = ", ".join(grp.name for grp in query.groups)
-        table = f"{self.schema}.{self._cube_to_table_name(query.cube)}"
+        table = f"{self.schema}.{self.cube_to_table_name(query.cube)}"
         order_by = ", ".join(f"{ob.dimension.name} {ob.direction.name}" for ob in query.orderings)
         where_parts = []
         params = {}
@@ -205,14 +205,14 @@ class PostgresCubeBackend(CubeBackend):
             return agg.name
         raise ValueError(f"Unsupported aggregation {agg}")
 
-    def _cube_to_table_name(self, cube: Type[Cube]):
+    def cube_to_table_name(self, cube: Type[Cube]):
         return cube.__name__.lower()
 
     def _init_table(self, cube: Type[Cube]):
         """
         Creates the corresponding db table if the table is not yet present.
         """
-        name = self._cube_to_table_name(cube)
+        name = self.cube_to_table_name(cube)
         fields = [
             f"{dim.name} {self._ch_type(dim)}"
             for dim in list(cube._dimensions.values()) + list(cube._metrics.values())
